function  plotfluxesL(T, I, L, range)
%fitPowerLaw Performs a power-law type fit on the input data
%
%   e = fitPowerLaw(X, Y)
%   Fits the input data, specified by the X and Y variables, according to a
%   power law fit of the form Y = e1 * X^(-e2). Output argument 'e' is a
%   vector of two elements, with e(1) = e1 and e(2) = e2.
%
%   e = fitPowerLaw(X, Y, init_vals)
%   As above, with an additional parameter of "init_vals", which should be
%   a vector of two elements, specifying the initial values for the fit
%   coefficients e(1) and e(2). If it is not given, the default parameters
%   of 5*10^9 and 3.262153178920480482 will be used.
%

if nargin < 4
    range = [nanmin(L) nanmax(L)];
end

% Figure Parameters
LW=2;
MSz=18;
FSz=12;
FWt='demi';
FName='Arial';
%--------------------------------------------------------------------------
POS=get(gcf,'Position');delete(gcf);
    figure('position',POS,'color','w',.....
   'defaultlinelinewidth',LW,... 
   'DefaultAxeslinewidth',LW,... 
   'DefaultTextFontName', 'FName',...
   'DefaultTextFontSize',FSz, ... 
   'DefaultAxesFontName', 'FName',...
   'DefaultAxesFontSize',FSz, ...  
   'DefaultLineMarkerSize', MSz,...
   'DefaultTextFontWeight',FWt,...
   'DefaultAxesFontWeight',FWt);
%--------------------------------------------------------------------------
ind=find(L>=range(1) & L<=range(2));

DT=1/24;
subplot(2,1,1)
[avg, avgT] = avgInSegments(I(ind,2), T(ind), DT);
plot(avgT, avg,'.-b');
set(gca,'xscale','lin','yscale','log'); grid on;
datetick('x','dd/mm');
xlabel ('Time'); 
ylim([1000 10000000]);
ylabel ('I (cm^{2}\cdotst\cdotsec\cdotkeV)^{-1}','fontsize',14,'fontweight','b');
h=legend('Channel 2 [56.7 keV]');
title(['Diff. fluxes at L = ',num2str(range(1)),' - ',num2str(range(2))]);
yticks=[1000  100000  10000000];

subplot(2,1,2)
[avg, avgT] = avgInSegments(I(ind,9), T(ind), DT);
plot(avgT, avg,'.-m');
set(gca,'xscale','lin','yscale','log'); grid on;
datetick('x','dd/mm');
xlabel ('Time'); 
ylim([1 100000]);
ylabel ('I (cm^{2}\cdotst\cdotsec\cdotkeV)^{-1}','fontsize',14,'fontweight','b');
h=legend('Channel 9 [1535 keV]');
title(['Diff. fluxes at L = ',num2str(range(1)),' - ',num2str(range(2))]);
yticks=[1  100 10000 ];


end
